@@ -1,14 +1,12 @@
 from __future__ import annotations
 
 from abc import abstractmethod
-from concurrent.futures._base import Executor
 from concurrent.futures._base import Future
 from concurrent.futures.process import ProcessPoolExecutor
 from functools import reduce
 from pathlib import Path
 from typing import Dict
 from typing import Iterable
-from typing import Optional
 from typing import Set
 from typing import Type
 from typing import TypeVar
@@ -58,11 +56,7 @@ class FileTask(Task[T]):
 
     @classmethod
     def run(
-        cls: Type[FileTask],
-        tasks: Iterable[FileTask],
-        *,
-        executor: Optional[Executor] = None,
-        overwrite: bool = _DEFAULT_OVERWRITE,
+        cls: Type[FileTask], tasks: Iterable[FileTask], *, overwrite: bool = _DEFAULT_OVERWRITE,
     ) -> None:
         tasks: Set[FileTask] = reduce(
             lambda x, y: x | {y} | y.get_dependencies(recurse=True), tasks, set(),
@@ -70,11 +64,7 @@ class FileTask(Task[T]):
         if not overwrite:
             tasks = {task for task in tasks if not Path(task.path()).exists()}
         futures: Dict[Task, Future] = {}
-        if executor is None:
-            executor_use = ProcessPoolExecutor()
-        else:
-            executor_use = executor
-        with executor_use as executor_cm:
+        with ProcessPoolExecutor() as executor:
             while tasks:
                 completed: Set[Task] = set()
                 for task in tasks:
@@ -84,7 +74,7 @@ class FileTask(Task[T]):
                         if all(
                             dep not in tasks for dep in task.get_dependencies(recurse=True)
                         ) and (task not in futures):
-                            futures[task] = executor_cm.submit(task, overwrite=overwrite)
+                            futures[task] = executor.submit(task, overwrite=overwrite)
                     else:
                         if future.done():
                             maybe_exception = future.exception()
